==> haskell-servant-0.13.0.1-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.13.0.1
id: servant-0.13.0.1-9rJiQMQB9iOKzqrHaEuCBo
key: servant-0.13.0.1-9rJiQMQB9iOKzqrHaEuCBo
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 17d2bbb4674e8b39a37b17622ccf0810
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Header
    Servant.API.HttpVersion Servant.API.Internal.Test.ComprehensiveAPI
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.QueryParam
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Utils.Enter
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-0.13.0.1
hs-libraries: HSservant-0.13.0.1-9rJiQMQB9iOKzqrHaEuCBo
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 text-1.2.3.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI
    attoparsec-0.13.2.2-KZXutHSJyFFFErNezqs0Rb
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    http-api-data-0.3.10-B4Uez9V5S9H629pPL7lR1w
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.2-Hp3f62sblzVJDS3ORILSVQ
    natural-transformation-0.4-H812UKihNmSBjnMSucJuXM
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    vault-0.3.1.2-DWs1Ilp1NsjdURE6EiVGL
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI=e763a4a7c222101a91911389c36d4497
             attoparsec-0.13.2.2-KZXutHSJyFFFErNezqs0Rb=00fe5c2fcfc4c1dbb030be8823e7ce5f
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             http-api-data-0.3.10-B4Uez9V5S9H629pPL7lR1w=cc0281b38bc3ebe242256b4f352e9671
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             http-types-0.12.2-Hp3f62sblzVJDS3ORILSVQ=0e3f56446088d76b8499612b29457455
             natural-transformation-0.4-H812UKihNmSBjnMSucJuXM=4bd55b0193d677b93b6dbf1f23bae4bb
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=c09e48de7c9591fe7d4e2ba81a9fcf9b
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=224d0377dd86bfef9c4c84d4841ba81f
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=2754b46212c00717aaae8361f03806b5
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             vault-0.3.1.2-DWs1Ilp1NsjdURE6EiVGL=bb0dce47b04431dc13377c3cac105c02
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.13.0.1-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.13.0.1
id: servant-0.13.0.1-DvERNH4kZYz8UvSq9vuHdN
key: servant-0.13.0.1-DvERNH4kZYz8UvSq9vuHdN
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: f2db06d7731896d7554f030ac945a2a0
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Header
    Servant.API.HttpVersion Servant.API.Internal.Test.ComprehensiveAPI
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.QueryParam
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Utils.Enter
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-0.13.0.1
hs-libraries: HSservant-0.13.0.1-DvERNH4kZYz8UvSq9vuHdN
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 text-1.2.3.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    aeson-1.4.1.0-DC05NYridW9CuV0L6TLprZ
    attoparsec-0.13.2.2-LRNbjQIitwn4Jmo3hCxwCI
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    http-api-data-0.3.10-pv7o8WJHUNyD79Ijv6A3
    http-media-0.7.1.3-DEqoMUzH7kXLeKubCF2x9V
    http-types-0.12.2-A3iO9yi4jtVBISyGmGh0IQ
    natural-transformation-0.4-H812UKihNmSBjnMSucJuXM
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    vault-0.3.1.2-DWs1Ilp1NsjdURE6EiVGL
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             aeson-1.4.1.0-DC05NYridW9CuV0L6TLprZ=2dabf93ee02d5485cbe316a08ea94024
             attoparsec-0.13.2.2-LRNbjQIitwn4Jmo3hCxwCI=4a615f6f9c3fdb3bc12ed255f597d820
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             http-api-data-0.3.10-pv7o8WJHUNyD79Ijv6A3=f2e03ed62c273a5a28cc4c0fd5f16a1a
             http-media-0.7.1.3-DEqoMUzH7kXLeKubCF2x9V=5e83f929be451e956bb1cd3fb8519c86
             http-types-0.12.2-A3iO9yi4jtVBISyGmGh0IQ=0dc8a0f99295ecdb31f6b687393563ad
             natural-transformation-0.4-H812UKihNmSBjnMSucJuXM=4bd55b0193d677b93b6dbf1f23bae4bb
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=c09e48de7c9591fe7d4e2ba81a9fcf9b
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=224d0377dd86bfef9c4c84d4841ba81f
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=2754b46212c00717aaae8361f03806b5
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             vault-0.3.1.2-DWs1Ilp1NsjdURE6EiVGL=bb0dce47b04431dc13377c3cac105c02
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
